@@ -21,6 +21,9 @@ class IcingaMultiEditForm extends DirectorObjectForm
 
     private $propertiesToPick;
 
+    /** @var array<string, string> Custom variable name map to its element's name in the form */
+    private $varNameMap = [];
+
     public function setObjects($objects)
     {
         $this->objects = $objects;
@@ -68,8 +71,7 @@ class IcingaMultiEditForm extends DirectorObjectForm
 
         /** @var \Zend_Form_Element $el */
         foreach ($this->getElements() as $el) {
-            $name = $el->getName();
-            if (substr($name, 0, 4) === 'var_') {
+            if ($this->isCustomVar($el->getName())) {
                 $this->makeVariants($el);
             }
         }
@@ -137,8 +139,8 @@ class IcingaMultiEditForm extends DirectorObjectForm
                 continue;
             }
 
-            if (substr($property, 0, 4) === 'var_') {
-                $property = 'vars.' . substr($property, 4);
+            if ($this->isCustomVar($property)) {
+                $property = 'vars.' . $this->varNameMap[$property];
             }
 
             foreach ($this->getObjects($objects) as $object) {
@@ -147,13 +149,26 @@ class IcingaMultiEditForm extends DirectorObjectForm
         }
     }
 
+    /**
+     * Check if the given property is a custom var
+     *
+     * @param string $property
+     *
+     * @return bool
+     */
+    protected function isCustomVar(string $property): bool
+    {
+        return substr($property, 0, 4) === 'var_';
+    }
+
     protected function storeModifiedObjects()
     {
         $modified = 0;
+        $store = $this->getDbObjectStore();
         foreach ($this->objects as $object) {
             if ($object->hasBeenModified()) {
                 $modified++;
-                $object->store();
+                $store->store($object);
             }
         }
 
@@ -221,6 +236,11 @@ class IcingaMultiEditForm extends DirectorObjectForm
         $key = $element->getName();
         $this->removeElement($key);
         $label = $element->getLabel();
+
+        if ($this->isCustomVar($key)) {
+            $this->varNameMap[$key] = $label;
+        }
+
         $group = $this->getDisplayGroupForElement($element);
         $description = $element->getDescription();
 
@@ -240,11 +260,13 @@ class IcingaMultiEditForm extends DirectorObjectForm
         }
     }
 
+
+
     protected function getVariants($key)
     {
         $variants = array();
-        if (substr($key, 0, 4) === 'var_') {
-            $key = 'vars.' . substr($key, 4);
+        if ($this->isCustomVar($key)) {
+            $key = 'vars.' . $this->varNameMap[$key];
         }
 
         foreach ($this->objects as $name => $object) {
@@ -309,8 +331,9 @@ class IcingaMultiEditForm extends DirectorObjectForm
             $this->translate($this->object->getShortTableName())
         );
 
+        $store = $this->getDbObjectStore();
         foreach ($this->objects as $object) {
-            $object->delete();
+            $store->delete($object);
         }
 
         if ($this->listUrl) {
